.. django-qanda documentation master file, created by
   sphinx-quickstart on Sun Sep 28 18:15:05 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django-Qanda's documentation!
========================================

.. image:: /images/qanda-threepage.png
   :alt: Demo screenshot of provided templates

Qanda is a simple FAQ app for `Django <https://www.djangoproject.com/>`_ projects.

Here are the main features:

- Published questions can be made public, restricted to logged-in users, or only
  visible to site staff.

- Topics are self-hiding depending on the access level of the questions they
  contain.

- Qanda installs with a fully working set of templates so you can start playing
  straight away, and an example project is provided.




Getting started
---------------

The first thing you'll need to do is check out the
:doc:`installation guide and requirements</install>`.

If you're familiar with installing Django apps then the installation is totally
standard, with no additional dependencies.



License
-------

Django-Qanda is released under the `MIT License <http://opensource.org/licenses/MIT>`_.



Contribute
----------

- Issue Tracker: https://bitbucket.org/mhurt/django-qanda/issues
- Source Code: https://bitbucket.org/mhurt/django-qanda/


.. toctree::
   :maxdepth: 2
   :hidden:

   install
   exampleproject
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
